@@ -92,4 +92,6 @@ class GalleryImageDownloader:
         return image_path
 
     def download_parallel(self, images_and_paths: List[Tuple[Image, str]])->List[str]:
-        return process_map(self.download, images_and_paths) #type: ignore
+        images = map(lambda tup:tup[0], images_and_paths)
+        paths = map(lambda tup:tup[1], images_and_paths)
+        return process_map(self.download, images, paths) #type: ignore
