@@ -1,3 +1,5 @@
+import os
+import wget
 from typing import Any, Dict, List, Optional
 from pydantic import Field
 import deeplabel.client
@@ -18,8 +20,14 @@ class Image(DeeplabelBase):
     image_id: str
     image_url: str
     name: str
+    annotation_url: Optional[str]
     parent_folder_id: Optional[str]
     resolution: ImageResolution = Field(default_factory=ImageResolution)  # type: ignore
+    
+    def download_annotations(self, folder_or_file_path:str):
+        if self.annotation_url is None:
+            raise ValueError(f"Image {self.image_id} has no annotation_url set.")
+        wget.download(self.annotation_url, out=folder_or_file_path) # type: ignore
 
     @classmethod
     def create(
@@ -66,7 +74,7 @@ class Image(DeeplabelBase):
     ) -> "Image":
         image = cls.from_search_params({"imageId": image_id}, client=client)
         if not len(image):
-            raise InvalidIdError(f"Failed to fetch video with videoId: {image_id}")
+            raise InvalidIdError(f"Failed to fetch image with imageId: {image_id}")
         return image[0]
 
     @classmethod
