@@ -38,17 +38,7 @@ class Image(DeeplabelBase):
     
     @classmethod
     def from_gallery_and_project_id(cls, gallery_id:str, project_id:str, client:"deeplabel.client.BaseClient")->List["Image"]:
-        return cls.from_search_params({"galleryId":gallery_id, "projectId":project_id, "limit":"-1"}, client=client)
-    
-    @classmethod
-    def from_image_id(cls, image_id: str, client: "deeplabel.client.BaseClient"):
-        images = cls.from_search_params({"imageId": image_id}, client)
-        if not len(images):
-            raise InvalidIdError(
-                f"Failed to fetch image with imageId  : {image_id}"
-            )
-        # since detectionId should fetch only 1 detection, return that detection instead of a list
-        return images[0]
+        return cls.from_search_params({"galleryId":gallery_id, "projectId":project_id, "limit":"-1"}, client=client)    
     
     def insert_detections(self, detections:List[Detection]):
         final_detections = []
